; The CMD file.
;
; Two parts: 1. Command definition and  2. State entry
; (state entry is after the commands def section)
;
; 1. Command definition
; ---------------------
; Note: The commands are CASE-SENSITIVE, and so are the command names.
; The eight directions are:
;   B, DB, D, DF, F, UF, U, UB     (all CAPS)
;   corresponding to back, down-back, down, downforward, etc.
; The six buttons are:
;   a, b, c, x, y, z               (all lower case)
;   In default key config, abc are are the bottom, and xyz are on the
;   top row. For 2 button characters, we recommend you use a and b.
;   For 6 button characters, use abc for kicks and xyz for punches.
;
; Each [Command] section defines a command that you can use for
; state entry, as well as in the CNS file.
; The command section should look like:
;
;   [Command]
;   Name= "some_name"
;   command = the_command
;   time = time (optional -- defaults to 15 if omitted)
;
; - some_name
;   A name to give that command. You'll use this name to refer to
;   that command in the state entry, as well as the CNS. It is case-
;   sensitive (QCB_a is NOT the same as Qcb_a or QCB_A).
;
; - command
;   list of buttons or directions, separated by commas.
;   Directions and buttons can be preceded by special characters:
;   slash (/) - means the key must be held down
;          egs. command = /D       ;hold the down direction
;               command = /F, a    ;hold fwd while you press a
;   tilde (~) - to detect key releases
;          egs. command = ~a       ;release the a button
;               command = ~D, F, a ;release down, press fwd, then a
;          If you want to detect "charge moves", you can specify
;          the time the key must be held down for (in game-ticks)
;          egs. command = ~30a     ;hold a for at least 30 ticks, then release
;               command = ~30
;   dollar ($) - Direction-only: detect as 4-way
;          egs. command = $D       ;will detect if D, DB or DF is held
;               command = $B       ;will detect if B, DB or UB is held
;   plus (+) - Buttons only: simultaneous press
;          egs. command = a+b      ;press a and b at the same time
;               command = x+y+z    ;press x, y and z at the same time
;   You can combine them:
;     eg. command = ~30$D, a+b     ;hold D, DB or DF for 30 ticks, release,
;                                  ;then press a and b together
;   It's recommended that for most "motion" commads, eg. quarter-circle-fwd,
;   you start off with a "release direction". This matches the way most
;   popular fighting games implement their engine.
;
; - time (optional)
;   Time allowed to do the command, given in game-ticks. Defaults to 15
;   if omitted
;
; If you have two or more commands with the same name, all of them will
; work. You can use it to allow multiple motions for the same move.
;
; Some common commands are given below. Delete, add, or modify as you wish.

;-| Super Motions |--------------------------------------------------------

[Command]
Name= "hadouken_ab"
command = ~D, DF, F, a+b

[Command]
Name= "hadouken_xy"
command = ~D, DF, F, x+y

[Command]
Name= "tatumaki_ab"
command = ~D, DB, B, a+b

[Command]
Name= "tatumaki_xy"
command = ~D, DB, B, x+y

[Command]
Name= "ac195"
command = x+y+z+a+b+c

[Command]
Name= "gggg"
command = x+y+z

[Command]
Name= "oz"
command = a+b+c

;-| Special Motions |------------------------------------------------------
;-----------------
; QCF
[Command]
Name= "hadouken_a"
command = ~D, DF, F, a

[Command]
Name= "hadouken_b"
command = ~D, DF, F, b

[Command]
Name= "hadouken_c"
command = ~D, DF, F, c

[Command]
Name= "hadouken_x"
command = ~D, DF, F, x

[Command]
Name= "hadouken_y"
command = ~D, DF, F, y

[Command]
Name= "hadouken_z"
command = ~D, DF, F, z

;-----------------
; QCB
[Command]
Name= "tatumaki_a"
command = ~D, DB, B, a

[Command]
Name= "tatumaki_b"
command = ~D, DB, B, b

[Command]
Name= "tatumaki_c"
command = ~D, DB, B, c

[Command]
Name= "tatumaki_x"
command = ~D, DB, B, x

[Command]
Name= "tatumaki_y"
command = ~D, DB, B, y

[Command]
Name= "tatumaki_z"
command = ~D, DB, B, z

;-----------------
; Uppercut
[Command]
Name= "uppercut_a"
command = ~F, D, DF, a

[Command]
Name= "uppercut_b"
command = ~F, D, DF, b

[Command]
Name= "shouryu_c"
command = ~F, D, DF, c

[Command]
Name= "uppercut_x"
command = ~F, D, DF, x

[Command]
Name= "uppercut_y"
command = ~F, D, DF, y

[Command]
Name= "shouryu_z"
command = ~F, D, DF, z


;--------------------
;Charge_Down_up
[Command]
Name= "chargedownup_a"
command = ~60$D, U, a
time = 10

[Command]
Name= "chargedownup_b"
command = ~60$D, U, b
time = 10

[Command]
Name= "chargedownup_c"
command = ~60$D, U, c
time = 10

[Command]
Name= "chargedownup_x"
command = ~60$D, U, x
time = 10

[Command]
Name= "chargedownup_y"
command = ~60$D, U, y
time = 10

[Command]
Name= "chargedownup_z"
command = ~60$D, U, z
time = 10

;--------------------
;Charge_Back_fwd
[Command]
Name= "chargebackfwd_a"
command = ~60$B, F, a
time = 10

[Command]
Name= "chargebackfwd_b"
command = ~60$B, F, b
time = 10

[Command]
Name= "chargedownup_c"
command = ~60$D, U, c
time = 10

[Command]
Name= "chargedownup_x"
command = ~60$D, U, x
time = 10

[Command]
Name= "chargedownup_y"
command = ~60$D, U, y
time = 10

[Command]
Name= "chargedownup_z"
command = ~60$D, U, z
time = 10



;-| Double Tap |-----------------------------------------------------------
[Command]
Name= "FF";Required (do not remove)
command = F, F
time = 10

[Command]
Name= "BB";Required (do not remove)
command = B, B
time = 10

[Command]
Name= "afd"
command = F, F
time = 8

[Command]
Name= "abd"
command = B, B
time = 8

;-| 2/3 Button Combination |-----------------------------------------------
[Command]
Name= "recovery";Required (do not remove)
command = a+x
time = 1

[Command]
Name= "recovery"
command = a+b
time = 1

[Command]
Name= "recovery"
command = x+y
time = 1

;-| Dir + Button |---------------------------------------------------------
[Command]
Name= "fwd_a"
command = /F,a
time = 1

[Command]
Name= "fwd_b"
command = /F,b
time = 1

[Command]
Name= "fwd_c"
command = /F,c
time = 1

[Command]
Name= "fwd_x"
command = /F,x
time = 1

[Command]
Name= "fwd_y"
command = /F,y
time = 1

[Command]
Name= "fwd_z"
command = /F,z
time = 1

[Command]
Name= "back_a"
command = /B,a
time = 1

[Command]
Name= "back_b"
command = /B,b
time = 1

[Command]
Name= "back_c"
command = /B,c
time = 1

[Command]
Name= "back_x"
command = /B,x
time = 1

[Command]
Name= "back_y"
command = /B,y
time = 1

[Command]
Name= "back_y"
command = /B,y
time = 1

[Command]
Name= "down_a"
command = /$D,a
time = 1

[Command]
Name= "down_b"
command = /$D,b
time = 1

[Command]
Name= "down_c"
command = /$D,c
time = 1

[Command]
Name= "fwd_ab"
command = /F, a+b
time = 1

[Command]
Name= "back_ab"
command = /B, a+b
time = 1

[Command]
Name= "fwd_ax"
command = /F, a+x
time = 1

;-| Single Button |---------------------------------------------------------
[Command]
Name= "a"
command = a
time = 1

[Command]
Name= "b"
command = b
time = 1

[Command]
Name= "c"
command = c
time = 1

[Command]
Name= "x"
command = x
time = 1

[Command]
Name= "y"
command = y
time = 1

[Command]
Name= "z"
command = z
time = 1

;-| Hold Dir |--------------------------------------------------------------
[Command]
Name= "holdfwd";Required (do not remove)
command = /$F
time = 1

[Command]
Name= "holdback";Required (do not remove)
command = /$B
time = 1

[Command]
Name= "holdup";Required (do not remove)
command = /$U
time = 1

[Command]
Name= "holddown";Required (do not remove)
command = /$D
time = 1


;---------------------------------------------------------------------------
; 2. State entry
; --------------
; This is where you define what commands bring you to what states.
;
; Each state entry block looks like:
;   [State -1]                  ;Don't change this
;   type = ChangeState          ;Don't change this
;   value = new_state_number
;   trigger1=command="command_name"
;   . . .  (any additional triggers)
;
; - new_state_number is the number of the state to change to
; - command_name is the name of the command (from the section above)
; - Useful triggers to know:
;   - statetype
;       S, C or A : current state-type of player (stand, crouch, air)
;   - ctrl
;       0 or 1 : 1 if player has control. Unless "interrupting" another
;                move, you'll want ctrl = 1
;   - stateno
;       number of state player is in - useful for "move interrupts"
;   - movecontact
;       0 or 1 : 1 if player's last attack touched the opponent
;                useful for "move interrupts"
;
; Note: The order of state entry is important.
;   State entry with a certain command must come before another state
;   entry with a command that is the subset of the first.  
;   For example, command "fwd_a" must be listed before "a", and
;   "fwd_ab" should come before both of the others.
;
; For reference on triggers, see CNS documentation.
;
; Just for your information (skip if you're not interested):
; This part is an extension of the CNS. "State -1" is a special state
; that is executed once every game-tick, regardless of what other state
; you are in. 


; Don't remove the following line. It's required by the CMD standard.
[Statedef -1]

;===========================================================================

; hadouken_ab
[State -1]
type = ChangeState
value = 3000
triggerall=command="hadouken_ab"
triggerall = power >= 1000 ;@@@@@@@@@@@p[1000ȏ̎̂ 
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = statetype != A ;@@@@@@@@@@@@Ԃ󒆈ȊO̎
trigger2 = hitdefattr = SC, NA, SA ,SP ,NP;@@@@@@1
trigger2 = movecontact = 1
trigger3 = stateno = 230
trigger3 = time >= 16
trigger4 = stateno = 1000
trigger5 = stateno = 1001
trigger6 = stateno = 1010
trigger7 = stateno = 1011
trigger8 = stateno = 1030
trigger9 = stateno = 1031

; hadouken_ab_a
[State -1]
type = ChangeState
value = 3001
triggerall=command="hadouken_ab"
triggerall = power >= 1000 ;@@@@@@@@@@@p[1000ȏ̎̂ 
trigger1 = statetype = A
trigger1 = ctrl = 1
trigger2 = stateno = 1002
trigger3 = stateno = 1003
trigger4 = stateno = 1020
trigger5 = stateno = 1021
trigger6 = stateno = 1040
trigger7 = stateno = 1041

; hadouken_xy
[State -1]
type = ChangeState
value = 3031
triggerall=command="hadouken_xy"
triggerall = power >= 1000 
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = statetype != A
trigger2 = hitdefattr = SC, NA, SA ,SP ,NP
trigger2 = movecontact = 1
trigger3 = stateno = 230
trigger3 = time >= 16
trigger4 = stateno = 1000
trigger5 = stateno = 1001
trigger6 = stateno = 1010
trigger7 = stateno = 1011
trigger8 = stateno = 1030
trigger9 = stateno = 1031


; hadouken_xy_a
[State -1]
type = ChangeState
value = 3030
triggerall=command="hadouken_xy"
triggerall = power >= 1000 
trigger1 = statetype = A
trigger1 = ctrl = 1
trigger2 = stateno = 1002
trigger3 = stateno = 1003
trigger4 = stateno = 1020
trigger5 = stateno = 1021
trigger6 = stateno = 1040
trigger7 = stateno = 1041


; tatumaki_ab
[State -1]
type = ChangeState
value = 3010
triggerall=command="tatumaki_ab"
triggerall = power >= 1000 ;@@@@@@@@@@@p[1000ȏ̎̂ 
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = statetype != A ;@@@@@@@@@@@@Ԃ󒆈ȊO̎
trigger2 = hitdefattr = SC, NA, SA ,SP ,NP;@@@@@@1
trigger2 = movecontact = 1
trigger3 = stateno = 230
trigger3 = time >= 16
trigger4 = stateno = 1000
trigger5 = stateno = 1001
trigger6 = stateno = 1010
trigger7 = stateno = 1011
trigger8 = stateno = 1030
trigger9 = stateno = 1031

; tatumaki_ab_a
[State -1]
type = ChangeState
value = 3011
triggerall=command="tatumaki_ab"
triggerall = power >= 1000 ;@@@@@@@@@@@p[1000ȏ̎̂ 
trigger1 = statetype = A
trigger1 = ctrl = 1
trigger2 = stateno = 1002
trigger3 = stateno = 1003
trigger4 = stateno = 1020
trigger5 = stateno = 1021
trigger6 = stateno = 1040
trigger7 = stateno = 1041


; tatumaki_xy
[State -1]
type = ChangeState
value = 3020
triggerall=command="tatumaki_xy"
triggerall = power >= 1000  
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = statetype != A
trigger2 = hitdefattr = SC, NA, SA ,SP ,NP
trigger2 = movecontact = 1
trigger3 = stateno = 230
trigger3 = time >= 16
trigger4 = stateno = 1000
trigger5 = stateno = 1001
trigger6 = stateno = 1010
trigger7 = stateno = 1011
trigger8 = stateno = 1030
trigger9 = stateno = 1031

;ac195
[State -1]
type = ChangeState
value = 4300
triggerall = power >= 1500
trigger1=command="ac195"
trigger1 = statetype = S
trigger1 = ctrl = 1
;trigger1 = NumHelper1 < 1
;trigger1 = NumHelper2 < 1
;trigger1 = NumHelper4 < 1
;trigger1 = NumHelper5 < 1
;trigger1 = NumHelper6 < 1
;trigger1 = NumHelper8 < 1
;trigger1 = NumHelper9 < 1
;trigger1 = NumHelper10 < 1

;gggg
[State -1]
type = ChangeState
value = 4100
triggerall = power >= 800
trigger1=command="gggg"
trigger1 = statetype = S
trigger1 = ctrl = 1
;trigger1 = NumHelper1 < 1
;trigger1 = NumHelper2 < 1
;trigger1 = NumHelper4 < 1
;trigger1 = NumHelper5 < 1

;oz
[State -1]
type = ChangeState
value = 4200
triggerall = power >= 800
trigger1=command="oz"
trigger1 = statetype = S
trigger1 = ctrl = 1
;trigger1 = NumHelper6 < 1
;trigger1 = NumHelper8 < 1
;trigger1 = NumHelper9 < 1
;trigger1 = NumHelper10 < 1

;---------------------------------------------------------------------

Guard_Run
[State -1]
type = ChangeState
value = 2222
trigger1=command="fwd_ax"
trigger1 = statetype != A
trigger1 = ctrl = 1

;===========================================================================

;hadouken_a
[State -1]
type = ChangeState
value = 1000
triggerall=command="hadouken_a"
triggerall = power >= 50
;triggerall = numproj = 0
trigger1 = statetype != A
trigger1 = ctrl = 1
trigger2 = stateno = 200
trigger2 = movecontact = 1
trigger3 = stateno = 210
trigger3 = movecontact = 1
trigger4 = stateno = 220
trigger4 = movecontact = 1
trigger5 = stateno = 230
trigger5 = time >= 16
trigger6 = stateno = 400
trigger6 = movecontact = 1
trigger7 = stateno = 410
trigger7 = movecontact = 1
trigger8 = stateno = 420
trigger8 = movecontact = 1
trigger9 = stateno = 221
trigger9 = movecontact = 1
trigger10 = stateno = 211
trigger10 = movecontact = 1


;hadouken_b
[State -1]
type = ChangeState
value = 1001
triggerall=command="hadouken_b"
triggerall = power >= 200
;triggerall = numproj = 0
trigger1 = statetype != A
trigger1 = ctrl = 1
trigger2 = stateno = 200
trigger2 = movecontact = 1
trigger3 = stateno = 210
trigger3 = movecontact = 1
trigger4 = stateno = 220
trigger4 = movecontact = 1
trigger5 = stateno = 230
trigger5 = time >= 16
trigger6 = stateno = 400
trigger6 = movecontact = 1
trigger7 = stateno = 410
trigger7 = movecontact = 1
trigger8 = stateno = 420
trigger8 = movecontact = 1
trigger9 = stateno = 221
trigger9 = movecontact = 1
trigger10 = stateno = 211
trigger10 = movecontact = 1


;hadouken_a_a
[State -1]
type = ChangeState
value = 1002
triggerall=command="hadouken_a"
triggerall = power >= 50
;triggerall = numproj = 0
trigger1 = statetype = A
trigger1 = ctrl = 1


;hadouken_b_a
[State -1]
type = ChangeState
value = 1003
triggerall=command="hadouken_b"
triggerall = power >= 200
;triggerall = numproj = 0
trigger1 = statetype = A
trigger1 = ctrl = 1


;---------------------------------------------------------------------------

;hadouken_x_a
[State -1]
type = ChangeState
value = 1040
triggerall=command="hadouken_x"
triggerall = power >= 50
;triggerall = numproj = 0
trigger1 = statetype = A
trigger1 = ctrl = 1

;hadouken_y_a
[State -1]
type = ChangeState
value = 1041
triggerall=command="hadouken_y"
triggerall = power >= 100
;triggerall = numproj = 0
trigger1 = statetype = A
trigger1 = ctrl = 1

;---------------------------------------------------------------------------

;tatumaki_a
[State -1]
type = ChangeState
value = 1010
triggerall=command="tatumaki_a"
triggerall = power >= 100
;triggerall = numproj = 0
trigger1 = statetype != A
trigger1 = ctrl = 1
trigger2 = stateno = 200
trigger2 = movecontact = 1
trigger3 = stateno = 210
trigger3 = movecontact = 1
trigger4 = stateno = 220
trigger4 = movecontact = 1
trigger5 = stateno = 230
trigger5 = time >= 16
trigger6 = stateno = 400
trigger6 = movecontact = 1
trigger7 = stateno = 410
trigger7 = movecontact = 1
trigger8 = stateno = 420
trigger8 = movecontact = 1
trigger9 = stateno = 221
trigger9 = movecontact = 1
trigger10 = stateno = 211
trigger10 = movecontact = 1


;tatumaki_b
[State -1]
type = ChangeState
value = 1011
triggerall=command="tatumaki_b"
triggerall = power >= 200
;triggerall = numproj = 0
trigger1 = statetype != A
trigger1 = ctrl = 1
trigger2 = stateno = 200
trigger2 = movecontact = 1
trigger3 = stateno = 210
trigger3 = movecontact = 1
trigger4 = stateno = 220
trigger4 = movecontact = 1
trigger5 = stateno = 230
trigger5 = time >= 16
trigger6 = stateno = 400
trigger6 = movecontact = 1
trigger7 = stateno = 410
trigger7 = movecontact = 1
trigger8 = stateno = 420
trigger8 = movecontact = 1
trigger9 = stateno = 221
trigger9 = movecontact = 1
trigger10 = stateno = 211
trigger10 = movecontact = 1

;tatumaki_a_a
[State -1]
type = ChangeState
value = 1020
triggerall=command="tatumaki_a"
triggerall = power >= 100
;triggerall = numproj = 0
trigger1 = statetype = A
trigger1 = ctrl = 1

;tatumaki_b_a
[State -1]
type = ChangeState
value = 1021
triggerall=command="tatumaki_b"
triggerall = power >= 200
;triggerall = numproj = 0
trigger1 = statetype = A
trigger1 = ctrl = 1

;---------------------------------------------------------------------------

;tatumaki_x
[State -1]
type = ChangeState
value = 1030
triggerall=command="tatumaki_x"
triggerall = power >= 100
;triggerall = numproj = 0
trigger1 = statetype != A
trigger1 = ctrl = 1
trigger2 = stateno = 200
trigger2 = movecontact = 1
trigger3 = stateno = 210
trigger3 = movecontact = 1
trigger4 = stateno = 220
trigger4 = movecontact = 1
trigger5 = stateno = 230
trigger5 = time >= 16
trigger6 = stateno = 400
trigger6 = movecontact = 1
trigger7 = stateno = 410
trigger7 = movecontact = 1
trigger8 = stateno = 420
trigger8 = movecontact = 1
trigger9 = stateno = 221
trigger9 = movecontact = 1
trigger10 = stateno = 211
trigger10 = movecontact = 1

;tatumaki_y
[State -1]
type = ChangeState
value = 1031
triggerall=command="tatumaki_y"
triggerall = power >= 150
;triggerall = numproj = 0
trigger1 = statetype != A
trigger1 = ctrl = 1
trigger2 = stateno = 200
trigger2 = movecontact = 1
trigger3 = stateno = 210
trigger3 = movecontact = 1
trigger4 = stateno = 220
trigger4 = movecontact = 1
trigger5 = stateno = 230
trigger5 = time >= 16
trigger6 = stateno = 400
trigger6 = movecontact = 1
trigger7 = stateno = 410
trigger7 = movecontact = 1
trigger8 = stateno = 420
trigger8 = movecontact = 1
trigger9 = stateno = 221
trigger9 = movecontact = 1
trigger10 = stateno = 211
trigger10 = movecontact = 1


;===========================================================================

;---------------------------------------------------------------------------
;RunFwd
[State -1]
type = ChangeState
value = 100
trigger1=command="FF"
trigger1 = statetype = S
trigger1 = ctrl = 1

;---------------------------------------------------------------------------
;RunBack
[State -1]
type = ChangeState
value = 105
trigger1=command="BB"
trigger1 = statetype = S
trigger1 = ctrl = 1

;===========================================================================

;hadouken_y_throw
[State -1]
type = ChangeState
value = 950
triggerall=command="hadouken_y"
trigger1 = statetype != A
trigger1 = ctrl = 1


;hadouken_y_throw_c
[State -1]
type = ChangeState
value = 960
triggerall=command="hadouken_y";p2 stand
trigger1 = statetype != A
trigger1 = ctrl = 1
trigger2 = stateno = 200
trigger2 = movecontact = 1
trigger3 = stateno = 210
trigger3 = movecontact = 1
trigger4 = stateno = 220
trigger4 = movecontact = 1
trigger5 = stateno = 230
trigger5 = time >= 16
trigger6 = stateno = 400
trigger6 = movecontact = 1
trigger7 = stateno = 410
trigger7 = movecontact = 1
trigger8 = stateno = 420
trigger8 = movecontact = 1
trigger9 = stateno = 221
trigger9 = movecontact = 1
trigger10 = stateno = 211
trigger10 = movecontact = 1

;---------------------------------------------------------------------------
;Stand_Throw (close dir+b)
; Complicated? Skip the throws and look at stand_a, etc, first.
; This is disabled right now. Remove the "null;" below when you
; want to use it.
[State -1]
type = ChangeState
value = 900
triggerall = statetype = S
triggerall = ctrl = 1
triggerall = p2bodydist X < 5 ;Near P2
trigger1=command="fwd_y";p2 stand
trigger1 = stateno != 100    ;Not running
trigger1 = p2statetype = S
;trigger1 = p2movetype != H
trigger2=command="fwd_y";p2 crouch
trigger2 = stateno != 100    ;Not running
trigger2 = p2statetype = C
;trigger2 = p2movetype != H
trigger3=command="back_y";p2 stand
trigger3 = p2statetype = S
;trigger3 = p2movetype != H
trigger4=command="back_y";p2 crouch
trigger4 = p2statetype = C
;trigger4 = p2movetype != H

;---------------------------------------------------------------------------
;Air_Throw1 (close dir+b)
; This is disabled right now. Remove the "null;" below when you
; want to use it.
[State -1]
type = null; ChangeState
value = 950
triggerall = statetype = A
triggerall = ctrl = 1
triggerall = p2bodydist X < 9
triggerall = p2bodydist Y > -22
triggerall = p2bodydist Y < 22
triggerall = p2statetype = A
triggerall = p2movetype != H
trigger1=command="fwd_b"
trigger2=command="back_b"

;---------------------------------------------------------------------------
;Stand_X
[State -1]
type = ChangeState
value = 200
triggerall=command="x";Place name of command here
triggerall=command !="holddown";Standing moves should have this line
 ;The following is true if Player is in stand state, and has control
trigger1 = statetype = S
trigger1 = ctrl = 1
 ;Uncomment the following if you want to be able to do a Stand_A rapidly
;trigger2 = stateno = 200
;trigger2 = time >= 16
trigger2 = stateno = 200
trigger2 = movecontact = 1


;---------------------------------------------------------------------------

;Stand_Y_r
[State -1]
type = ChangeState
value = 211
triggerall=command="y"
triggerall=command !="holddown"
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger1 = stateno = 100

;Stand_Y
[State -1]
type = ChangeState
value = 210
triggerall=command="y"
triggerall=command !="holddown"
trigger1 = statetype = S
trigger1 = ctrl = 1
 ;Uncomment the following if you want to be able to "chain" the attack
 ;from a Stand_A (state 200)
trigger2 = stateno = 200
trigger2 = movecontact = 1  ;If move hits, or is guarded by opponent
trigger3 = stateno = 400
trigger3 = movecontact = 1
trigger4 = stateno = 220
trigger4 = movecontact = 1
trigger5 = stateno = 420
trigger5 = movecontact = 1
trigger6 = stateno = 221
trigger6 = movecontact = 1

;---------------------------------------------------------------------------
;Stand_A_r
[State -1]
type = ChangeState
value = 221
triggerall=command="a"
triggerall=command !="holddown"
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger1 = stateno = 100

;Stand_A
[State -1]
type = ChangeState
value = 220
triggerall=command="a"
triggerall=command !="holddown"
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = stateno = 200
trigger2 = movecontact = 1
trigger3 = stateno = 400
trigger3 = movecontact = 1

;---------------------------------------------------------------------------
;Stand_B
[State -1]
type = ChangeState
value = 230
triggerall=command="b"
triggerall=command !="holddown"
triggerall = power >= 100
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = stateno = 200
trigger2 = movecontact = 1
trigger3 = stateno = 210
trigger3 = movecontact = 1
trigger4 = stateno = 220
trigger4 = movecontact = 1
trigger5 = stateno = 400
trigger5 = movecontact = 1
trigger6 = stateno = 410
trigger6 = movecontact = 1
trigger7 = stateno = 420
trigger7 = movecontact = 1
trigger8 = stateno = 211
trigger8 = movecontact = 1
trigger9 = stateno = 221
trigger9 = movecontact = 1

;---------------------------------------------------------------------------
;Crouch_X
[State -1]
type = ChangeState
value = 400
triggerall=command="x"
triggerall=command="holddown"
trigger1 = statetype = C
trigger1 = ctrl = 1

;---------------------------------------------------------------------------
;Crouch_Y
[State -1]
type = ChangeState
value = 410
triggerall=command="y"
triggerall=command="holddown"
trigger1 = statetype = C
trigger1 = ctrl = 1
trigger2 = stateno = 200
trigger2 = movecontact = 1
trigger3 = stateno = 400
trigger3 = movecontact = 1
trigger4 = stateno = 220
trigger4 = movecontact = 1
trigger5 = stateno = 420
trigger5 = movecontact = 1
trigger6 = stateno = 221
trigger6 = movecontact = 1

;---------------------------------------------------------------------------
;Crouch_A
[State -1]
type = ChangeState
value = 420
triggerall=command="a"
triggerall=command="holddown"
trigger1 = statetype = C
trigger1 = ctrl = 1
trigger2 = stateno = 200
trigger2 = movecontact = 1
trigger3 = stateno = 400
trigger3 = movecontact = 1

;---------------------------------------------------------------------------
;Crouch_B
[State -1]
type = ChangeState
value = 430
triggerall=command="b"
triggerall=command="holddown"
triggerall = power >= 100
trigger1 = statetype = C
trigger1 = ctrl = 1
trigger2 = stateno = 200
trigger2 = movecontact = 1
trigger3 = stateno = 210
trigger3 = movecontact = 1
trigger4 = stateno = 220
trigger4 = movecontact = 1
trigger5 = stateno = 400
trigger5 = movecontact = 1
trigger6 = stateno = 410
trigger6 = movecontact = 1
trigger7 = stateno = 420
trigger7 = movecontact = 1
trigger8 = stateno = 211
trigger8 = movecontact = 1
trigger9 = stateno = 221
trigger9 = movecontact = 1

;---------------------------------------------------------------------------
;Jump_X
[State -1]
type = ChangeState
value = 600
trigger1=command="x"
trigger1 = statetype = A
trigger1 = ctrl = 1

;---------------------------------------------------------------------------
;Jump_Y
[State -1]
type = ChangeState
value = 610
trigger1=command="y"
trigger1 = statetype = A
trigger1 = ctrl = 1

;---------------------------------------------------------------------------
;Jump_A
[State -1]
type = ChangeState
value = 620
trigger1=command="a"
trigger1 = statetype = A
trigger1 = ctrl = 1

;---------------------------------------------------------------------------
;Jump_B
[State -1]
type = ChangeState
value = 630
trigger1=command="b"
trigger1 = statetype = A
trigger1 = ctrl = 1

;-| Special Motions |------------------------------------------------------

;-| Helper |------------------------------------------------------

;Sand
[State -1]
type = ChangeState
value = 4030
triggerall = power >= 200
trigger1=command="shouryu_z"
trigger1 = statetype != A
trigger1 = ctrl = 1
;trigger1 = NumHelper4 < 1

;Death
[State -1]
type = ChangeState
value = 4020
triggerall = power >= 200
trigger1=command="hadouken_z"
trigger1 = statetype != A
trigger1 = ctrl = 1
;trigger1 = NumHelper2 < 1

;Nataku
[State -1]
type = ChangeState
value = 4040
triggerall = power >= 200
trigger1=command="tatumaki_z"
trigger1 = statetype != A
trigger1 = ctrl = 1
;trigger1 = NumHelper5 < 1

;Wing
[State -1]
type = ChangeState
value = 4000
triggerall = power >= 200
trigger1=command="z"
trigger1 = statetype = S
trigger1 = ctrl = 1
;trigger1 = NumHelper1 < 1

;Epyon
[State -1]
type = ChangeState
value = 4080
triggerall = power >= 200
trigger1=command="shouryu_c"
trigger1 = statetype != A
trigger1 = ctrl = 1
;trigger1 = NumHelper10 < 1

;Vay
[State -1]
type = ChangeState
value = 4060
triggerall = power >= 200
trigger1=command="hadouken_c"
trigger1 = statetype != A
trigger1 = ctrl = 1
;trigger1 = NumHelper8 < 1

;Mer
[State -1]
type = ChangeState
value = 4070
triggerall = power >= 200
trigger1=command="tatumaki_c"
trigger1 = statetype != A
trigger1 = ctrl = 1
;trigger1 = NumHelper9 < 1

;Tall
[State -1]
type = ChangeState
value = 4050
triggerall = power >= 200
trigger1=command="c"
trigger1 = statetype = S
trigger1 = ctrl = 1
;trigger1 = NumHelper6 < 1

;---------------------------------------------------------------------

Jump_Run_f
[State -1]
type = ChangeState
value = 2000
trigger1=command="afd"
trigger1 = statetype = A
trigger1 = ctrl = 1


Jump_Run_b
[State -1]
type = ChangeState
value = 2001
trigger1=command="abd"
trigger1 = statetype = A
trigger1 = ctrl = 1